@@ -28,7 +28,9 @@ class Neighbor:
         self.resolvers[l2,l3]=resolve_method
 
     def resolve(self, l2inst, l3inst):
-        return self.resolvers[l2inst.__class__,l3inst.__class__](l2inst,l3inst)
+        k = l2inst.__class__,l3inst.__class__
+        if k in self.resolvers:
+            return self.resolvers[k](l2inst,l3inst)
 
     def __repr__(self):
         return "\n".join("%-15s -> %-15s" % (l2.__name__, l3.__name__) for l2,l3 in self.resolvers)
@@ -44,13 +46,13 @@ def getmacbyip(ip, chainCC=0):
     tmp = map(ord, inet_aton(ip))
     if (tmp[0] & 0xf0) == 0xe0: # mcast @
         return "01:00:5e:%.2x:%.2x:%.2x" % (tmp[1]&0x7f,tmp[2],tmp[3])
-    iff,a,gw = config.conf.route.route(ip)
-    if ( (iff == "lo") or (ip == config.conf.route.get_if_bcast(iff)) ):
+    iff,a,gw = conf.route.route(ip)
+    if ( (iff == "lo") or (ip == conf.route.get_if_bcast(iff)) ):
         return "ff:ff:ff:ff:ff:ff"
     if gw != "0.0.0.0":
         ip = gw
 
-    mac = config.conf.netcache.arp_cache.get(ip)
+    mac = conf.netcache.arp_cache.get(ip)
     if mac:
         return mac
 
@@ -63,7 +65,7 @@ def getmacbyip(ip, chainCC=0):
                nofilter=1)
     if res is not None:
         mac = res.payload.hwsrc
-        config.conf.netcache.arp_cache[ip] = mac
+        conf.netcache.arp_cache[ip] = mac
         return mac
     return None
 
@@ -79,7 +81,7 @@ class DestMACField(MACField):
             x = conf.neighbor.resolve(pkt,pkt.payload)
             if x is None:
                 x = "ff:ff:ff:ff:ff:ff"
-                warning("Mac address to reach destination not found")
+                warning("Mac address to reach destination not found. Using broadcast.")
         return MACField.i2h(self, pkt, x)
     def i2m(self, pkt, x):
         return MACField.i2m(self, pkt, self.i2h(pkt, x))
@@ -153,7 +155,7 @@ class Ether(Packet):
 class Dot3(Packet):
     __metaclass__ = Ether_or_Dot3_metaclass
     name = "802.3"
-    fields_desc = [ MACField("dst", ETHER_BROADCAST),
+    fields_desc = [ DestMACField("dst"),
                     MACField("src", ETHER_ANY),
                     LenField("len", None, "H") ]
     def extract_padding(self,s):
@@ -173,6 +175,9 @@ class LLC(Packet):
                     XByteField("ssap", 0x00),
                     ByteField("ctrl", 0) ]
 
+conf.neighbor.register_l3(Ether, LLC, lambda l2,l3: conf.neighbor.resolve(l2,l3.payload))
+conf.neighbor.register_l3(Dot3, LLC, lambda l2,l3: conf.neighbor.resolve(l2,l3.payload))
+
 
 class CookedLinux(Packet):
     name = "cooked linux"
@@ -190,6 +195,8 @@ class SNAP(Packet):
     fields_desc = [ X3BytesField("OUI",0x000000),
                     XShortEnumField("code", 0x000, ETHER_TYPES) ]
 
+conf.neighbor.register_l3(Dot3, SNAP, lambda l2,l3: conf.neighbor.resolve(l2,l3.payload))
+
 
 class Dot1Q(Packet):
     name = "802.1Q"
@@ -221,7 +228,7 @@ class Dot1Q(Packet):
             return self.sprintf("802.1q (%Dot1Q.type%) vlan %Dot1Q.vlan%")
 
             
-
+conf.neighbor.register_l3(Ether, Dot1Q, lambda l2,l3: conf.neighbor.resolve(l2,l3.payload))
 
 class STP(Packet):
     name = "Spanning Tree Protocol"
